
TODO: TODO_19_67_22_89: remove `ignored_func_ids_list`

Instead, load unmapped `func_id`-s as `FuncState.fs_unplugged`.

There should be a place in the tree where these `func_id`-s should be plugged into.
Another `CompositeNodeType`?

